@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0702';
+our $VERSION = '0.0703';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -20,6 +20,20 @@ use strictures 2;
 use namespace::clean;
 
 
+has notes => (
+    is      => 'ro',
+    lazy    => 1,
+    builder => 1,
+);
+sub _build_notes {
+    my $self = shift;
+    return [ get_scale_notes( $self->tonic ) ];
+}
+
+
+has size => ( is => 'ro', default => sub { 3 } );
+
+
 has rootless => ( is => 'ro', default => sub { 0 } );
 
 
@@ -29,9 +43,6 @@ has octave => ( is => 'ro', default => sub { 4 } );
 has concert => ( is => 'ro', default => sub { 440 } );
 
 
-has size => ( is => 'ro', default => sub { 3 } );
-
-
 has tonic => ( is => 'ro', default => sub { 'C' } );
 
 
@@ -49,18 +60,7 @@ sub _build_temper {
 }
 
 
-has notes => (
-    is      => 'ro',
-    lazy    => 1,
-    builder => 1,
-);
-sub _build_notes {
-    my $self = shift;
-    return [ get_scale_notes( $self->tonic ) ];
-}
-
-
-has midikey   => ( is => 'ro', default => sub { 69 } );
+has midikey => ( is => 'ro', default => sub { 69 } );
 
 
 has scale => (
@@ -383,7 +383,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0702
+version 0.0703
 
 =head1 SYNOPSIS
 
@@ -428,55 +428,10 @@ mean, the measurements of the notes and the intervals between them.
 For Western notes and intervals, this tonality begins with the C<C>
 note.  That is, all intervals are calculated from C<C>.  So, if you
 want to analyze a minor chord, either make it start on C<C> (like
-C<[C Eb G]>) or somewhere between C<C> and B<B> (like C<[D F A]>).
+C<[C Eb G]>) or somewhere between C<C> and C<B> (like C<[D F A]>).
 
 =head1 ATTRIBUTES
 
-=head2 rootless
-
-Show chord names with no root.
-
-Default: C<0>
-
-=head2 octave
-
-The octave to use in internal computations.
-
-Default: C<4>
-
-=head2 concert
-
-Concert pitch to use in internal computations.
-
-Default: C<440>
-
-=head2 size
-
-Chord size
-
-Default: C<3>
-
-=head2 tonic
-
-The root of the computations.
-
-Default: C<C>
-
-* Currently (and for the foreseeable future) this will remain the only value
-that produces sane results.
-
-=head2 semitones
-
-Number of notes in the scale, used in internal computations.
-
-Default: C<12>
-
-=head2 temper
-
-Physical distance between notes, used in internal computations.
-
-Default: C<semitones * 100 / log(2)>
-
 =head2 notes
 
 The actual notes to use in the computation.
@@ -507,8 +462,55 @@ For B<natural_intervals> this last example produces the following:
 Note that case matters for interval names.  For example, "M" means major and "m"
 means minor.
 
+=head2 size
+
+Chord size
+
+Default: C<3>
+
+=head2 rootless
+
+Show chord names with no root.
+
+Default: C<0>
+
+=head2 octave
+
+The octave to use in internal computations.
+
+Default: C<4>
+
+=head2 concert
+
+Concert pitch to use in internal computations.
+
+Default: C<440>
+
+=head2 tonic
+
+The root of the computations.
+
+Default: C<C>
+
+* Currently (and for the foreseeable future) this will remain the only value
+that produces sane results.
+
+=head2 semitones
+
+Number of notes in the scale, used in internal computations.
+
+Default: C<12>
+
+=head2 temper
+
+Physical distance between notes, used in internal computations.
+
+Default: C<semitones * 100 / log(2)>
+
 =head2 midikey
 
+Describe this...
+
 Default: C<69>
 
 =head2 scale
@@ -525,22 +527,40 @@ Create a new C<Music::Intervals> object.
 
 =head2 chord_names
 
+Chord names of the B<size> note combinations.
+
 =head2 integer_notation
 
+Math!  See source...
+
 =head2 eq_tempered_cents
 
+The Equal tempered cents.
+
 =head2 eq_tempered_frequencies
 
+The Equal tempered frequencies.
+
 =head2 eq_tempered_intervals
 
+The Equal tempered intervals.
+
 =head2 natural_cents
 
+Just intonation cents.
+
 =head2 natural_frequencies
 
+Just intonation frequencies.
+
 =head2 natural_intervals
 
+Just intonation intervals.
+
 =head2 natural_prime_factors
 
+Just intonation prime factors.
+
 =head2 dyads
 
 Return pairs of the given notes with fractional and pitch ratio parts.
